# Copyright (c) 2003 Sylvain Thnault (thenault@nerim.net)
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

__author__ = u"Sylvain Thnault"
__revision__ = "$Id: __init__.py,v 1.3 2003/05/28 15:14:34 syt Exp $"

from logilab.common.interface import Interface

from astng_objects import *
from manager import ASTNGManager, ASTNGBuildingException

class IASTNGVisitor(Interface):
    """ interface for checker which prefers receive events according to statement type
    """
    
    def visit_module(self, node):
        raise NotImplementedError()
    
    def visit_classdef(self, node):
        raise NotImplementedError()
    
    def visit_funcdef(self, node):
        raise NotImplementedError()
    
    def visit_ifstmt(self, node):
        raise NotImplementedError()
    
    def visit_elifstmt(self, node):
        raise NotImplementedError()
    
    def visit_whilestmt(self, node):
        raise NotImplementedError()
    
    def visit_exceptstmt(self, node):
        raise NotImplementedError()
    
    def visit_forstmt(self, node):
        raise NotImplementedError()
    
    def visit_trystmt(self, node):
        raise NotImplementedError()
    
    def visit_elsestmt(self, node):
        raise NotImplementedError()
    
    def visit_finallystmt(self, node):
        raise NotImplementedError()
    
    def visit_passstmt(self, node):
        raise NotImplementedError()
    
    def visit_continuestmt(self, node):
        raise NotImplementedError()
    
    def visit_breakstmt(self, node):
        raise NotImplementedError()
    
    def visit_raisestmt(self, node):
        raise NotImplementedError()
    
    def visit_assertstmt(self, node):
        raise NotImplementedError()
    
    def visit_globalstmt(self, node):
        raise NotImplementedError()
    
    def visit_printstmt(self, node):
        raise NotImplementedError()
    
    def visit_returnstmt(self, node):
        raise NotImplementedError()
    
    def visit_yieldstmt(self, node):
        raise NotImplementedError()
    
    def visit_execstmt(self, node):
        raise NotImplementedError()
    
    def visit_importstmt(self, node):
        raise NotImplementedError()
    
    def visit_expressionstmt(self, node):
        raise NotImplementedError()
    
    def visit_assignmentstmt(self, node):
        raise NotImplementedError()
    
    def visit_stringstmt(self, node):
        raise NotImplementedError()


class ASTNGHandler:
    """ default handler for ASTNG visitors
    
    (pass to each event)
    """
    __implements__ = IASTNGVisitor
    
    def visit_module(self, node):
        pass
    def visit_classdef(self, node):
        pass
    def visit_funcdef(self, node):
        pass
    def visit_ifstmt(self, node):
        pass
    def visit_elifstmt(self, node):
        pass
    def visit_whilestmt(self, node):
        pass
    def visit_exceptstmt(self, node):
        pass
    def visit_forstmt(self, node):
        pass
    def visit_trystmt(self, node):
        pass
    def visit_elsestmt(self, node):
        pass
    def visit_finallystmt(self, node):
        pass
    def visit_passstmt(self, node):
        pass
    def visit_continuestmt(self, node):
        pass
    def visit_breakstmt(self, node):
        pass
    def visit_raisestmt(self, node):
        pass
    def visit_printstmt(self, node):
        pass
    def visit_returnstmt(self, node):
        pass
    def visit_yieldstmt(self, node):
        pass
    def visit_execstmt(self, node):
        pass
    def visit_importstmt(self, node):
        pass
    def visit_expressionstmt(self, node):
        pass
    def visit_assignmentstmt(self, node):
        pass
    def visit_assertstmt(self, node):
        pass
    def visit_globalstmt(self, node):
        pass
    def visit_stringstmt(self, node):
        pass

__all__ = ('IASTNGVisitor', 'ASTNGHandler',
           'ASTNGBuildingException', 'ASTNGManager')
