# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
""" Copyright (c) 2002-2003 LOGILAB S.A. (Paris, FRANCE).
 http://www.logilab.fr/ -- mailto:contact@logilab.fr

add an abstraction level to transparently import optik classes from optparse
(python >= 2.3) or the optik package.
It also defines three new types for optik/optparse command line parser :

  _ regexp
    argument of this type will be converted using re.compile
  _ csv
    argument of this type will be converted using split(',')
  _ yn
    argument of this type will be true if 'y' or 'yes', false if 'n' or 'no'
    
"""

try:
    from optparse import OptionParser as BaseParser, Option as BaseOption, \
         OptionGroup, OptionValueError, Values
except:
    from optik import OptionParser as BaseParser, Option as BaseOption, \
         OptionGroup, OptionValueError, Values
    
import re
from copy import copy

def check_regexp(option, opt, value):
    try:
        return re.compile(value)
    except ValueError:
        raise OptionValueError(
            "option %s: invalid regexp value: %r" % (opt, value))
    
def check_csv(option, opt, value):
    try:
        return [s.strip() for s in value.split(',')]
    except ValueError:
        raise OptionValueError(
            "option %s: invalid regexp value: %r" % (opt, value))

def check_yn(option, opt, value):
    if value in ('y', 'yes'):
        return 1
    if value in ('n', 'no'):
        return 0
    msg = "option %s: invalid yn value %r, should be in (y, yes, n, no)"
    raise OptionValueError(msg % (opt, value))


class Option (BaseOption):
    TYPES = BaseOption.TYPES + ("regexp", "csv", 'yn')
    TYPE_CHECKER = copy(BaseOption.TYPE_CHECKER)
    TYPE_CHECKER["regexp"] = check_regexp
    TYPE_CHECKER["csv"] = check_csv
    TYPE_CHECKER["yn"] = check_yn

    
class OptionParser(BaseParser):
    def __init__(self, option_class=Option, *args, **kwargs):
        BaseParser.__init__(self, option_class=Option, *args, **kwargs)
        
    
__all__ = ('OptionParser', 'Option', 'OptionGroup', 'OptionValueError', 'Values')
